@@ -1,9 +1,10 @@
 package Text::Levenshtein::XS;
 use 5.008_008;
-require Exporter;
 
-@Text::Levenshtein::XS::ISA = qw/Exporter/;
-$Text::Levenshtein::XS::VERSION = '0.30_03';
+require Exporter;
+*import = \&Exporter::import;
+
+$Text::Levenshtein::XS::VERSION = '0.1';
 @Text::Levenshtein::XS::EXPORT_OK = qw/distance/;
 
 eval {
@@ -20,18 +21,12 @@ eval {
 
 
 sub distance {
-    return Text::Levenshtein::XS::xs_distance( [unpack('U*', defined $_[0]?$_[0]:'')], [unpack('U*', defined $_[1]?$_[1]:'')] );
+    # shift shift is faster than $_[0] $_[1]
+    return Text::Levenshtein::XS::xs_distance( [unpack('U*', shift)], [unpack('U*',shift)]);
 }
 
-
-
 1;
 
-
-
-__END__
-
-
 =encoding utf8
 
 =head1 NAME
@@ -40,20 +35,20 @@ Text::Levenshtein::XS - XS Levenshtein edit distance.
 
 =head1 SYNOPSIS
 
-    use Text::Levenshtein::XS qw/distance/;
+	use Text::Levenshtein::XS qw/distance/;
 
-    print distance('Neil','Niel');
-    # prints 2
+	print distance('Neil','Niel');
+	# prints 2
 
 =head1 DESCRIPTION
 
 Returns the number of edits (insert,delete,substitute) required to turn the source string into the target string. XS implementation (requires a C compiler). Works correctly with utf8.
 
-    use Text::Levenshtein::XS qw/distance/;
-    use utf8;
+	use Text::Levenshtein::XS qw/distance/;
+	use utf8;
 
-    distance('ⓕⓞⓤⓡ','ⓕⓤⓞⓡ'), 
-    # prints 2
+	distance('ⓕⓞⓤⓡ','ⓕⓤⓞⓡ'), 
+	# prints 2
 
 =head1 METHODS
 
@@ -66,14 +61,16 @@ Returns: int that represents the edit distance between the two argument. Stops c
 
 Wrapper function to take the edit distance between a source and target string using XS algorithm implementation.
 
-    use Text::Levenshtein::XS qw/distance/;
-    print distance('Neil','Niel');
-    # prints 2
+	use Text::Levenshtein::XS qw/distance/;
+	print distance('Neil','Niel');
+	# prints 2
 
 =head1 NOTES
 
 Drop in replacement for L<Text::LevenshteinXS>
 
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -92,7 +89,7 @@ Drop in replacement for L<Text::LevenshteinXS>
 
 Please report bugs to:
 
-L<https://github.com/ugexe/Text--Levenshtein--XS/issues>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Levenshtein-XS>
 
 =head1 AUTHOR
 
